@@ -16,13 +16,22 @@ try:
 except ImportError:
 	pass
 
-logger = logging.getLogger("fence_aws")
+logger = logging.getLogger()
 logger.propagate = False
 logger.setLevel(logging.INFO)
 logger.addHandler(SyslogLibHandler())
 logging.getLogger('botocore.vendored').propagate = False
 
-def get_instance_id():
+status = {
+		"running": "on",
+		"stopped": "off",
+		"pending": "unknown",
+		"stopping": "unknown",
+		"shutting-down": "unknown",
+		"terminated": "unknown"
+}
+
+def get_instance_id(options):
 	try:
 		token = requests.put('http://169.254.169.254/latest/api/token', headers={"X-aws-ec2-metadata-token-ttl-seconds" : "21600"}).content.decode("UTF-8")
 		r = requests.get('http://169.254.169.254/latest/meta-data/instance-id', headers={"X-aws-ec2-metadata-token" : token}).content.decode("UTF-8")
@@ -30,23 +39,34 @@ def get_instance_id():
 	except HTTPError as http_err:
 		logger.error('HTTP error occurred while trying to access EC2 metadata server: %s', http_err)
 	except Exception as err:
-		logger.error('A fatal error occurred while trying to access EC2 metadata server: %s', err)
+		if "--skip-race-check" not in options:
+			logger.error('A fatal error occurred while trying to access EC2 metadata server: %s', err)
+		else:
+			logger.debug('A fatal error occurred while trying to access EC2 metadata server: %s', err)
 	return None
-	
+
 
 def get_nodes_list(conn, options):
-	logger.info("Starting monitor operation")
+	logger.debug("Starting monitor operation")
 	result = {}
 	try:
 		if "--filter" in options:
 			filter_key   = options["--filter"].split("=")[0].strip()
 			filter_value = options["--filter"].split("=")[1].strip()
 			filter = [{ "Name": filter_key, "Values": [filter_value] }]
-			for instance in conn.instances.filter(Filters=filter):
-				result[instance.id] = ("", None)
-		else:
-			for instance in conn.instances.all():
-				result[instance.id] = ("", None)
+			logging.debug("Filter: {}".format(filter))
+
+		for instance in conn.instances.filter(Filters=filter if 'filter' in vars() else []):
+			instance_name = ""
+			for tag in instance.tags or []:
+				if tag.get("Key") == "Name":
+					instance_name = tag["Value"]
+			try:
+				result[instance.id] = (instance_name, status[instance.state["Name"]])
+			except KeyError as e:
+				if options.get("--original-action") == "list-status":
+					logger.error("Unknown status \"{}\" returned for {} ({})".format(instance.state["Name"], instance.id, instance_name))
+				result[instance.id] = (instance_name, "unknown")
 	except ClientError:
 		fail_usage("Failed: Incorrect Access Key or Secret Key.")
 	except EndpointConnectionError:
@@ -63,14 +83,12 @@ def get_power_status(conn, options):
 	try:
 		instance = conn.instances.filter(Filters=[{"Name": "instance-id", "Values": [options["--plug"]]}])
 		state = list(instance)[0].state["Name"]
-		logger.info("Status operation for EC2 instance %s returned state: %s",options["--plug"],state.upper())
-		if state == "running":
-			return "on"
-		elif state == "stopped":
-			return "off"
-		else:
+		logger.debug("Status operation for EC2 instance %s returned state: %s",options["--plug"],state.upper())
+		try:
+			return status[state]
+		except KeyError as e:
+			logger.error("Unknown status \"{}\" returned".format(state))
 			return "unknown"
-
 	except ClientError:
 		fail_usage("Failed: Incorrect Access Key or Secret Key.")
 	except EndpointConnectionError:
@@ -78,7 +96,7 @@ def get_power_status(conn, options):
 	except IndexError:
 		fail(EC_STATUS)
 	except Exception as e:
-		logging.error("Failed to get power status: %s", e)
+		logger.error("Failed to get power status: %s", e)
 		fail(EC_STATUS)
 
 def get_self_power_status(conn, instance_id):
@@ -86,10 +104,10 @@ def get_self_power_status(conn, instance_id):
 		instance = conn.instances.filter(Filters=[{"Name": "instance-id", "Values": [instance_id]}])
 		state = list(instance)[0].state["Name"]
 		if state == "running":
-			logging.debug("Captured my (%s) state and it %s - returning OK - Proceeding with fencing",instance_id,state.upper())
+			logger.debug("Captured my (%s) state and it %s - returning OK - Proceeding with fencing",instance_id,state.upper())
 			return "ok"
 		else:
-			logging.debug("Captured my (%s) state it is %s - returning Alert - Unable to fence other nodes",instance_id,state.upper())
+			logger.debug("Captured my (%s) state it is %s - returning Alert - Unable to fence other nodes",instance_id,state.upper())
 			return "alert"
 	
 	except ClientError:
@@ -100,19 +118,20 @@ def get_self_power_status(conn, instance_id):
 		return "fail"
 
 def set_power_status(conn, options):
-	my_instance = get_instance_id()
+	my_instance = get_instance_id(options)
 	try:
 		if (options["--action"]=="off"):
-			if (get_self_power_status(conn,my_instance) == "ok"):
+			if "--skip-race-check" in options or get_self_power_status(conn,my_instance) == "ok":
 				conn.instances.filter(InstanceIds=[options["--plug"]]).stop(Force=True)
-				logger.info("Called StopInstance API call for %s", options["--plug"])
+				logger.debug("Called StopInstance API call for %s", options["--plug"])
 			else:
-				logger.info("Skipping fencing as instance is not in running status")
+				logger.debug("Skipping fencing as instance is not in running status")
 		elif (options["--action"]=="on"):
 			conn.instances.filter(InstanceIds=[options["--plug"]]).start()
 	except Exception as e:
-		logger.error("Failed to power %s %s: %s", \
+		logger.debug("Failed to power %s %s: %s", \
 				options["--action"], options["--plug"], e)
+		fail(EC_STATUS)
 
 def define_new_opts():
 	all_opt["region"] = {
@@ -142,7 +161,7 @@ def define_new_opts():
 	all_opt["filter"] = {
 		"getopt" : ":",
 		"longopt" : "filter",
-		"help" : "--filter=[key=value]           Filter (e.g. vpc-id=[vpc-XXYYZZAA]",
+		"help" : "--filter=[key=value]           Filter (e.g. vpc-id=[vpc-XXYYZZAA])",
 		"shortdesc": "Filter for list-action",
 		"required": "0",
 		"order": 5
@@ -156,12 +175,20 @@ def define_new_opts():
 		"default": "False",
 		"order": 6
 	}
+	all_opt["skip_race_check"] = {
+		"getopt" : "",
+		"longopt" : "skip-race-check",
+		"help" : "--skip-race-check              Skip race condition check",
+		"shortdesc": "Skip race condition check",
+		"required": "0",
+		"order": 7
+	}
 
 # Main agent method
 def main():
 	conn = None
 
-	device_opt = ["port", "no_password", "region", "access_key", "secret_key", "filter", "boto3_debug"]
+	device_opt = ["port", "no_password", "region", "access_key", "secret_key", "filter", "boto3_debug", "skip_race_check"]
 
 	atexit.register(atexit_handler)
 
@@ -173,7 +200,7 @@ def main():
 
 	docs = {}
 	docs["shortdesc"] = "Fence agent for AWS (Amazon Web Services)"
-	docs["longdesc"] = "fence_aws is an I/O Fencing agent for AWS (Amazon Web\
+	docs["longdesc"] = "fence_aws is a Power Fencing agent for AWS (Amazon Web\
 Services). It uses the boto3 library to connect to AWS.\
 \n.P\n\
 boto3 can be configured with AWS CLI or by creating ~/.aws/credentials.\n\
@@ -183,12 +210,15 @@ For instructions see: https://boto3.readthedocs.io/en/latest/guide/quickstart.ht
 
 	run_delay(options)
 
-	if options.get("--verbose") is not None:
-		lh = logging.FileHandler('/var/log/fence_aws_debug.log')
+	if "--debug-file" in options:
+		for handler in logger.handlers:
+			if isinstance(handler, logging.FileHandler):
+				logger.removeHandler(handler)
+		lh = logging.FileHandler(options["--debug-file"])
 		logger.addHandler(lh)
 		lhf = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
 		lh.setFormatter(lhf)
-		logger.setLevel(logging.DEBUG)
+		lh.setLevel(logging.DEBUG)
 	
 	if options["--boto3_debug"].lower() not in ["1", "yes", "on", "true"]:
 		boto3.set_stream_logger('boto3',logging.INFO)
@@ -213,7 +243,10 @@ For instructions see: https://boto3.readthedocs.io/en/latest/guide/quickstart.ht
 				      aws_access_key_id=access_key,
 				      aws_secret_access_key=secret_key)
 	except Exception as e:
-		fail_usage("Failed: Unable to connect to AWS: " + str(e))
+		if not options.get("--action", "") in ["metadata", "manpage", "validate-all"]:
+			fail_usage("Failed: Unable to connect to AWS: " + str(e))
+		else:
+			pass
 
 	# Operate the fencing device
 	result = fence_action(conn, options, set_power_status, get_power_status, get_nodes_list)
