@@ -1,30 +1,53 @@
 #!@PYTHON@ -tt
 
 import sys
-import pycurl, io, json
+import pycurl
+import io
+import json
 import logging
 import atexit
-import time
+
 sys.path.append("@FENCEAGENTSLIBDIR@")
-from fencing import *
-from fencing import fail, run_delay, EC_LOGIN_DENIED, EC_STATUS
+from fencing import all_opt, atexit_handler, check_input, process_input, show_docs, fence_action, fail, run_delay, EC_STATUS
 
 state = {
 	 "ACTIVE": "on",
 	 "SHUTOFF": "off",
+	 "HARD_REBOOT": "on",
+	 "SOFT_REBOOT": "on",
 	 "ERROR": "unknown"
 }
 
 def get_token(conn, options):
-        try:
-                command = "identity/token"
-                action = "grant_type=urn%3Aibm%3Aparams%3Aoauth%3Agrant-type%3Aapikey&apikey={}".format(options["--token"])
-                res = send_command(conn, command, "POST", action, printResult=False)
-        except Exception as e:
-                logging.debug("Failed: {}".format(e))
-                return "TOKEN_IS_MISSING_OR_WRONG"
-
-        return res["access_token"]
+	try:
+		if options["--token"][0] == '@':
+			key_file = options["--token"][1:]
+			try:
+				# read the API key from a file
+				with open(key_file, "r") as f:
+					try:
+						keys = json.loads(f.read())
+						# data seems to be in json format
+						# return the value of the item with the key 'Apikey'
+						api_key = keys.get("Apikey", "")
+						if not api_key:
+							# backward compatibility: former key name was 'apikey'
+							api_key = keys.get("apikey", "")
+					# data is text, return as is
+					except ValueError:
+						api_key = f.read().strip()
+			except FileNotFoundError:
+				logging.debug("Failed: Cannot open file {}".format(key_file))
+				return "TOKEN_IS_MISSING_OR_WRONG"
+		else:
+			api_key = options["--token"]
+		command = "identity/token"
+		action = "grant_type=urn%3Aibm%3Aparams%3Aoauth%3Agrant-type%3Aapikey&apikey={}".format(api_key)
+		res = send_command(conn, command, "POST", action, printResult=False)
+	except Exception as e:
+		logging.debug("Failed: {}".format(e))
+		return "TOKEN_IS_MISSING_OR_WRONG"
+	return res["access_token"]
 
 def get_list(conn, options):
 	outlets = {}
@@ -37,21 +60,30 @@ def get_list(conn, options):
 		return outlets
 
 	for r in res["pvmInstances"]:
-		if "--verbose" in options:
+		if options["--verbose-level"] > 1:
 			logging.debug(json.dumps(r, indent=2))
-		outlets[r["pvmInstanceID"]] = (r["serverName"], state[r["status"]])
+		outlets[r["pvmInstanceID"]] = (r["serverName"], state.get(r["status"], "unknown"))
 
 	return outlets
 
 def get_power_status(conn, options):
+	outlets = {}
+	logging.debug("Info: getting power status for LPAR " + options["--plug"] + " instance " + options["--instance"])
 	try:
 		command = "cloud-instances/{}/pvm-instances/{}".format(
 				options["--instance"], options["--plug"])
 		res = send_command(conn, command)
-		result = get_list(conn, options)[options["--plug"]][1]
+		outlets[res["pvmInstanceID"]] = (res["serverName"], state[res["status"]])
+		if options["--verbose-level"] > 1:
+			logging.debug(json.dumps(res, indent=2))
+		result = outlets[options["--plug"]][1]
+		logging.debug("Info: Status: {}".format(result))
 	except KeyError as e:
-		logging.debug("Failed: Unable to get status for {}".format(e))
-		fail(EC_STATUS)
+		try:
+			result = get_list(conn, options)[options["--plug"]][1]
+		except KeyError as ex:
+			logging.debug("Failed: Unable to get status for {}".format(ex))
+			fail(EC_STATUS)
 
 	return result
 
@@ -61,6 +93,7 @@ def set_power_status(conn, options):
 		"off" : '{"action" : "immediate-shutdown"}',
 	}[options["--action"]]
 
+	logging.debug("Info: set power status to " + options["--action"] + " for LPAR " + options["--plug"] + " instance " + options["--instance"])
 	try:
 		send_command(conn, "cloud-instances/{}/pvm-instances/{}/action".format(
 				options["--instance"], options["--plug"]), "POST", action)
@@ -68,6 +101,25 @@ def set_power_status(conn, options):
 		logging.debug("Failed: Unable to set power to {} for {}".format(options["--action"], e))
 		fail(EC_STATUS)
 
+def reboot_cycle(conn, options):
+	action = {
+		"reboot" :  '{"action" : "hard-reboot"}',
+	}[options["--action"]]
+
+	logging.debug("Info: start reboot cycle with action " + options["--action"] + " for LPAR " + options["--plug"] + " instance " + options["--instance"])
+	try:
+		send_command(conn, "cloud-instances/{}/pvm-instances/{}/action".format(
+				options["--instance"], options["--plug"]), "POST", action)
+	except Exception as e:
+		result = get_power_status(conn, options)
+		logging.debug("Info: Status {}".format(result))
+		if result == "off":
+			return True
+		else:
+			logging.debug("Failed: Unable to cycle with {} for {}".format(options["--action"], e))
+			fail(EC_STATUS)
+	return True
+
 def connect(opt, token):
 	conn = pycurl.Curl()
 
@@ -99,7 +151,10 @@ def auth_connect(opt):
 	conn = pycurl.Curl()
 
 	# setup correct URL
-	conn.base_url = "https://iam.cloud.ibm.com/"
+	if opt["--api-type"] == "private":
+		conn.base_url = "https://private.iam.cloud.ibm.com/"
+	else:
+		conn.base_url = "https://iam.cloud.ibm.com/"
 
 	if opt["--verbose-level"] > 1:
 		conn.setopt(pycurl.VERBOSE, 1)
@@ -200,21 +255,21 @@ def define_new_opts():
 		"order" : 0
 	}
 	all_opt["api-type"] = {
-                "getopt" : ":",
-                "longopt" : "api-type",
-                "help" : "--api-type=[public|private]          API-type: 'public' (default) or 'private'",
-                "required" : "0",
-                "shortdesc" : "API-type (public|private)",
-                "order" : 0
-        }
+		"getopt" : ":",
+		"longopt" : "api-type",
+		"help" : "--api-type=[public|private]          API-type: 'public' (default) or 'private'",
+		"required" : "0",
+		"shortdesc" : "API-type (public|private)",
+		"order" : 0
+	}
 	all_opt["proxy"] = {
-                "getopt" : ":",
-                "longopt" : "proxy",
-                "help" : "--proxy=[http://<URL>:<PORT>]          Proxy: 'http://<URL>:<PORT>'",
-                "required" : "0",
-                "shortdesc" : "Network proxy",
-                "order" : 0
-        }
+		"getopt" : ":",
+		"longopt" : "proxy",
+		"help" : "--proxy=[http://<URL>:<PORT>]          Proxy: 'http://<URL>:<PORT>'",
+		"required" : "0",
+		"shortdesc" : "Network proxy",
+		"order" : 0
+	}
 
 
 def main():
@@ -227,15 +282,16 @@ def main():
 		"proxy",
 		"port",
 		"no_password",
+		"method",
 	]
 
 	atexit.register(atexit_handler)
 	define_new_opts()
 
 	all_opt["shell_timeout"]["default"] = "500"
-	all_opt["power_timeout"]["default"] = "30"
-	all_opt["power_wait"]["default"] = "1"
-	all_opt["stonith_status_sleep"]["default"] = "2"
+	all_opt["power_timeout"]["default"] = "120"
+	all_opt["power_wait"]["default"] = "15"
+	all_opt["stonith_status_sleep"]["default"] = "10"
 	all_opt["api-type"]["default"] = "private"
 	all_opt["proxy"]["default"] = ""
 
@@ -243,8 +299,8 @@ def main():
 
 	docs = {}
 	docs["shortdesc"] = "Fence agent for IBM PowerVS"
-	docs["longdesc"] = """fence_ibm_powervs is an I/O Fencing agent which can be \
-used with IBM PowerVS to fence virtual machines."""
+	docs["longdesc"] = """fence_ibm_powervs is a power fencing agent for \
+IBM Power Virtual Server (IBM PowerVS) to fence virtual server instances."""
 	docs["vendorurl"] = "https://www.ibm.com"
 	show_docs(options, docs)
 
@@ -259,7 +315,7 @@ used with IBM PowerVS to fence virtual machines."""
 	conn = connect(options, token)
 	atexit.register(disconnect, conn)
 
-	result = fence_action(conn, options, set_power_status, get_power_status, get_list)
+	result = fence_action(conn, options, set_power_status, get_power_status, get_list, reboot_cycle)
 
 	sys.exit(result)
 
