@@ -48,6 +48,8 @@ def main():
 
 	docs = {}
 	docs["shortdesc"] = "Fence agent for HP Moonshot iLO"
+	docs["longdesc"] = "fence_ilo_moonshot is a Power Fencing agent \
+for HP Moonshot iLO."
 	docs["longdesc"] = ""
 	docs["vendorurl"] = "http://www.hp.com"
 	show_docs(options, docs)
