@@ -81,39 +81,6 @@ trim (char *str)
     return (strlen (str));
 }
 
-static int
-read_message (const fence_kdump_node_t *node, void *msg, int len)
-{
-    int error;
-    char addr[NI_MAXHOST];
-    char port[NI_MAXSERV];
-    struct sockaddr_storage ss;
-    socklen_t size = sizeof (ss);
-
-    error = recvfrom (node->socket, msg, len, 0, (struct sockaddr *) &ss, &size);
-    if (error < 0) {
-        log_error (2, "recvfrom (%s)\n", strerror (errno));
-        goto out;
-    }
-
-    error = getnameinfo ((struct sockaddr *) &ss, size,
-                         addr, sizeof (addr),
-                         port, sizeof (port),
-                         NI_NUMERICHOST | NI_NUMERICSERV);
-    if (error != 0) {
-        log_error (2, "getnameinfo (%s)\n", gai_strerror (error));
-        goto out;
-    }
-
-    error = strcasecmp (node->addr, addr);
-    if (error != 0) {
-        log_debug (1, "discard message from '%s'\n", addr);
-    }
-
-out:
-    return (error);
-}
-
 static int
 do_action_monitor (void)
 {
@@ -151,6 +118,12 @@ do_action_off (const fence_kdump_opts_t *opts)
     fence_kdump_msg_t msg;
     fence_kdump_node_t *node;
     struct timeval timeout;
+    struct addrinfo hints;
+    fence_kdump_node_t *check_node;
+    char addr[NI_MAXHOST];
+    char port[NI_MAXSERV];
+    struct sockaddr_storage ss;
+    socklen_t size = sizeof (ss);
 
     if (list_empty (&opts->nodes)) {
         return (1);
@@ -164,7 +137,41 @@ do_action_off (const fence_kdump_opts_t *opts)
     FD_ZERO (&rfds);
     FD_SET (node->socket, &rfds);
 
-    log_debug (0, "waiting for message from '%s'\n", node->addr);
+    // create listening socket
+    memset (&hints, 0, sizeof (hints));
+
+    hints.ai_family = opts->family;
+    hints.ai_socktype = SOCK_DGRAM;
+    hints.ai_protocol = IPPROTO_UDP;
+    hints.ai_flags = AI_NUMERICSERV;
+
+    hints.ai_family = node->info->ai_family;
+    hints.ai_flags |= AI_PASSIVE;
+
+    freeaddrinfo (node->info);
+
+    node->info = NULL;
+    error = getaddrinfo (NULL, node->port, &hints, &node->info);
+    if (error != 0) {
+        log_error (2, "getaddrinfo (%s)\n", gai_strerror (error));
+        free_node (node);
+        return (1);
+    }
+
+    error = bind (node->socket, node->info->ai_addr, node->info->ai_addrlen);
+    if (error != 0) {
+        log_error (2, "bind (%s)\n", strerror (errno));
+        free_node (node);
+        return (1);
+    }
+
+    list_for_each_entry (check_node, &opts->nodes, list) {
+        log_debug (0, "waiting for message from '%s'\n", check_node->addr);
+	if (node->info->ai_family != check_node->info->ai_family) {
+            log_error (0, "mixing IPv4 and IPv6 nodes is not supported\n");
+            return (1);
+	}
+    }
 
     for (;;) {
         error = select (node->socket + 1, &rfds, NULL, NULL, &timeout);
@@ -177,7 +184,18 @@ do_action_off (const fence_kdump_opts_t *opts)
             break;
         }
 
-        if (read_message (node, &msg, sizeof (msg)) != 0) {
+        error = recvfrom (node->socket, &msg, sizeof (msg), 0, (struct sockaddr *) &ss, &size);
+        if (error < 0) {
+            log_error (2, "recvfrom (%s)\n", strerror (errno));
+            continue;
+        }
+
+        error = getnameinfo ((struct sockaddr *) &ss, size,
+                             addr, sizeof (addr),
+                             port, sizeof (port),
+                             NI_NUMERICHOST | NI_NUMERICSERV);
+        if (error != 0) {
+            log_error (2, "getnameinfo (%s)\n", gai_strerror (error));
             continue;
         }
 
@@ -186,14 +204,22 @@ do_action_off (const fence_kdump_opts_t *opts)
             continue;
         }
 
-        switch (msg.version) {
-        case FENCE_KDUMP_MSGV1:
-            log_debug (0, "received valid message from '%s'\n", node->addr);
-            return (0);
-        default:
-            log_debug (1, "invalid message version '0x%X'\n", msg.version);
-            continue;
+        // check if we have matched messages from any known node
+        list_for_each_entry (check_node, &opts->nodes, list) {
+            error = strcasecmp (check_node->addr, addr);
+            if (error == 0 ) {
+                switch (msg.version) {
+                case FENCE_KDUMP_MSGV1:
+                    log_debug (0, "received valid message from '%s'\n", addr);
+                    return (0);
+                default:
+                    log_debug (1, "invalid message version '0x%X'\n", msg.version);
+                    continue;
+                }
+            }
         }
+    log_debug (1, "discard message from '%s'\n", addr);
+
     }
 
     return (1);
@@ -209,7 +235,7 @@ do_action_metadata (const char *self)
     fprintf (stdout, "fence_kdump is an I/O fencing agent to be used with the kdump\n"
                      "crash recovery service. When the fence_kdump agent is invoked,\n"
                      "it will listen for a message from the failed node that acknowledges\n"
-                     "that the failed node it executing the kdump crash kernel.\n"
+                     "that the failed node is executing the kdump crash kernel.\n"
                      "Note that fence_kdump is not a replacement for traditional\n"
                      "fencing methods. The fence_kdump agent can only detect that a\n"
                      "node has entered the kdump crash recovery service. This allows the\n"
@@ -220,18 +246,21 @@ do_action_metadata (const char *self)
                      "message is received from the failed node, the node is considered to be\n"
                      "fenced and the agent returns success. Failure to receive a valid\n"
                      "message from the failed node in the given timeout period results in\n"
-                     "fencing failure.");
+                     "fencing failure. When multiple node names/IP addresses are specified\n"
+                     "a single valid message is sufficient for success. This is useful when\n"
+                     "single node can send message via several different IP addresses.\n");
     fprintf (stdout, "</longdesc>\n");
     fprintf (stdout, "<vendor-url>http://www.kernel.org/pub/linux/utils/kernel/kexec/</vendor-url>\n");
 
     fprintf (stdout, "<parameters>\n");
 
     fprintf (stdout, "\t<parameter name=\"nodename\" unique=\"0\" required=\"0\">\n");
-    fprintf (stdout, "\t\t<getopt mixed=\"-n, --nodename=NODE\" />\n");
+    fprintf (stdout, "\t\t<getopt mixed=\"-n, --nodename=NODE[,NODE...]\" />\n");
     fprintf (stdout, "\t\t<content type=\"string\" />\n");
     fprintf (stdout, "\t\t<shortdesc lang=\"en\">%s</shortdesc>\n",
-             "Name or IP address of node to be fenced. This option is required for\n"
-             "the \"off\" action.");
+             "List of names or IP addresses of node to be fenced. This option is\n"
+	     "required for the \"off\" action. Multiple values separated by commas\n"
+	     "can be specified. All values must be of same IP network family." );
     fprintf (stdout, "\t</parameter>\n");
 
     fprintf (stdout, "\t<parameter name=\"ipport\" unique=\"0\" required=\"0\">\n");
@@ -311,7 +340,7 @@ print_usage (const char *self)
     fprintf (stdout, "Options:\n");
     fprintf (stdout, "\n");
     fprintf (stdout, "%s\n",
-             "  -n, --nodename=NODE          Name or IP address of node to be fenced");
+             "  -n, --nodename=NODE[,NODE...]List of names or IP addresses of node to be fenced");
     fprintf (stdout, "%s\n",
              "  -p, --ipport=PORT            IP port number (default: 7410)");
     fprintf (stdout, "%s\n",
@@ -373,19 +402,6 @@ get_options_node (fence_kdump_opts_t *opts)
         return (1);
     }
 
-    hints.ai_family = node->info->ai_family;
-    hints.ai_flags |= AI_PASSIVE;
-
-    freeaddrinfo (node->info);
-
-    node->info = NULL;
-    error = getaddrinfo (NULL, node->port, &hints, &node->info);
-    if (error != 0) {
-        log_error (2, "getaddrinfo (%s)\n", gai_strerror (error));
-        free_node (node);
-        return (1);
-    }
-
     node->socket = socket (node->info->ai_family,
                            node->info->ai_socktype,
                            node->info->ai_protocol);
@@ -395,13 +411,6 @@ get_options_node (fence_kdump_opts_t *opts)
         return (1);
     }
 
-    error = bind (node->socket, node->info->ai_addr, node->info->ai_addrlen);
-    if (error != 0) {
-        log_error (2, "bind (%s)\n", strerror (errno));
-        free_node (node);
-        return (1);
-    }
-
     list_add_tail (&node->list, &opts->nodes);
 
     return (0);
@@ -521,6 +530,8 @@ main (int argc, char **argv)
 {
     int error = 1;
     fence_kdump_opts_t opts;
+    char *ptr;
+    char *node_list;
 
     init_options (&opts);
 
@@ -537,13 +548,24 @@ main (int argc, char **argv)
             log_error (0, "action 'off' requires nodename\n");
             exit (1);
         }
-        if (get_options_node (&opts) != 0) {
-            log_error (0, "failed to get node '%s'\n", opts.nodename);
-            exit (1);
+        node_list = (char *)malloc(strlen(opts.nodename)+1);
+
+        strcpy(node_list, opts.nodename); //make local copy of nodename on which we can safely iterate
+        // iterate through node_list
+        for (ptr = strtok(node_list, ","); ptr != NULL; ptr = strtok(NULL, ",")) {
+            set_option_nodename (&opts, ptr); //overwrite nodename for next function
+            if (get_options_node (&opts) != 0) {
+                log_error (0, "failed to get node '%s'\n", opts.nodename);
+                exit (1);
+            }
         }
+        free(node_list);
     }
 
     if (verbose != 0) {
+        //clear nodename to avoid showing just last nodename here
+        free(opts.nodename);
+        opts.nodename = NULL;
         print_options (&opts);
     }
 
